@@ -220,11 +220,11 @@ muse_test_flux_check_cubes(muse_datacube **aCubes, unsigned short aNCubes)
 } /* muse_test_flux_check_cubes() */
 
 #define PRINT_USAGE(rc)                                                        \
-  fprintf(stderr, "\nUsage: %s [ -profile <gaussian | moffat | circle | square> ]"\
-          "[ -select <flux | distance> ] [ -smooth <none | median | ppoly> ] " \
-          "DATACUBE_STD STD_FLUX_TABLE EXTINCTION_TABLE\n"                     \
-          "  The output STD_RESPONSE is written to a file starting with the "  \
-          "same basename as DATACUBE_STD.\n\n\n", argv[0]);                    \
+  fprintf(stderr, "\nUsage: %s [ -profile <gaussian | moffat | smoffat | "     \
+          "circle | square | auto> ] [ -select <flux | distance> ] [ -smooth " \
+          "<none | median | ppoly> ] DATACUBE_STD STD_FLUX_TABLE "             \
+          "EXTINCTION_TABLE\n  The output STD_RESPONSE is written to a file "  \
+          "starting with the same basename as DATACUBE_STD.\n\n\n", argv[0]);  \
   return (rc);
 
 int
@@ -236,7 +236,7 @@ muse_test_flux_integrate_from_cube(int argc, char **argv)
   char *incube = NULL,
        *inref = NULL,
        *inext = NULL;
-  muse_flux_profile_type profile = MUSE_FLUX_PROFILE_MOFFAT;
+  muse_flux_profile_type profile = MUSE_FLUX_PROFILE_AUTO;
   muse_flux_selection_type select = MUSE_FLUX_SELECT_NEAREST;
   muse_spectrum_smooth_type smooth = MUSE_SPECTRUM_SMOOTH_PPOLY;
 
@@ -249,12 +249,16 @@ muse_test_flux_integrate_from_cube(int argc, char **argv)
       if (i < argc) {
         if (!strncmp(argv[i], "moffat", 7)) {
           profile = MUSE_FLUX_PROFILE_MOFFAT;
+        } else if (!strncmp(argv[i], "smoffat", 8)) {
+          profile = MUSE_FLUX_PROFILE_SMOFFAT;
         } else if (!strncmp(argv[i], "gaussian", 9)) {
           profile = MUSE_FLUX_PROFILE_GAUSSIAN;
         } else if (!strncmp(argv[i], "circle", 7)) {
           profile = MUSE_FLUX_PROFILE_CIRCLE;
         } else if (!strncmp(argv[i], "square", 7)) {
           profile = MUSE_FLUX_PROFILE_EQUAL_SQUARE;
+        } else if (!strncmp(argv[i], "auto", 5)) {
+          profile = MUSE_FLUX_PROFILE_AUTO;
         }
       } else {
         PRINT_USAGE(2);
@@ -524,7 +528,7 @@ int main(int argc, char **argv)
    * muse_flux_integrate_std(), we can now use muse_flux_integrate_cube() *
    * on the existing cube which is much faster.                           */
   int i;
-  for (i = MUSE_FLUX_PROFILE_EQUAL_SQUARE; i >= MUSE_FLUX_PROFILE_MOFFAT; i--) {
+  for (i = MUSE_FLUX_PROFILE_AUTO; i >= MUSE_FLUX_PROFILE_MOFFAT; i--) {
     if (i == MUSE_FLUX_PROFILE_MOFFAT) {
       /* in the last iteration, for the moffat profile, test the (success) *
        * case where the DIMM measurements are missing from the cube header */
@@ -646,7 +650,7 @@ int main(int argc, char **argv)
   /* test failure cases of muse_flux_integrate_std(), too */
   muse_flux_object *fobj3 = muse_flux_object_new();
   state = cpl_errorstate_get();
-  rc = muse_flux_integrate_std(pt, MUSE_FLUX_PROFILE_EQUAL_SQUARE + 1, fobj3);
+  rc = muse_flux_integrate_std(pt, MUSE_FLUX_PROFILE_AUTO + 1, fobj3);
   cpl_test(rc == CPL_ERROR_ILLEGAL_INPUT && !cpl_errorstate_is_equal(state));
   cpl_errorstate_set(state);
   rc = muse_flux_integrate_std(NULL, MUSE_FLUX_PROFILE_MOFFAT, fobj3);
@@ -680,7 +684,7 @@ int main(int argc, char **argv)
            cpl_error_get_code() == CPL_ERROR_NULL_INPUT);
   cpl_errorstate_set(state);
   cpl_test_null(image);
-  image = muse_flux_integrate_cube(fluxobj->cube, ap, MUSE_FLUX_PROFILE_EQUAL_SQUARE + 1);
+  image = muse_flux_integrate_cube(fluxobj->cube, ap, MUSE_FLUX_PROFILE_AUTO + 1);
   cpl_test(!cpl_errorstate_is_equal(state) &&
            cpl_error_get_code() ==CPL_ERROR_ILLEGAL_INPUT);
   cpl_errorstate_set(state);
